==> tengits_widgets-0.0.4.tar.gz: lib/chart/src/style/chart_common_style.dart <==
import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class TLChartCommonStyle {
  ///
  static Color toolTipBgColor = Colors.black.withOpacity(0.8);

  ///
  static BarTooltipItem getBarTooltipItem(String text, {Color? color}) {
    return BarTooltipItem(
      text,
      TextStyle(
        color: color ?? Colors.white,
        fontSize: 12.sp,
        fontWeight: FontWeight.w400,
      ),
      textAlign: TextAlign.left,
    );
  }

  ///
  static FlBorderData flBorderData = FlBorderData(
    show: true,
    border: Border.symmetric(
      horizontal: BorderSide(color: const Color(0xFFF2F3F5), width: 1.w),
      vertical: BorderSide(color: Colors.transparent, width: 16.w),
    ),
  );

  static FlGridData getGridData(double? horizontalInterval) {
    return FlGridData(
      show: true,
      drawHorizontalLine: true,
      drawVerticalLine: false,
      horizontalInterval: horizontalInterval,
      getDrawingHorizontalLine: (double value) {
        return FlLine(color: const Color(0xFFF2F3F5), strokeWidth: 1);
      },
    );
  }

  // static LineTooltipItem getLineTooltipItems(Color? color, String text) {
  //   final textStyle = TextStyle(
  //     color: color,
  //     fontWeight: FontWeight.w400,
  //     fontSize: 12.sp,
  //   );
  //   return LineTooltipItem(text, textStyle, textAlign: TextAlign.left);
  // }

  // static List<TouchedSpotIndicatorData?> getTouchedSpotIndicator(LineChartBarData barData, List<int> indicators) {
  //   return indicators.map((int index) {
  //     final flLine = FlLine(color: const Color(0xFF5DACFB), strokeWidth: 0.5);

  //     final dotData = FlDotData();

  //     return TouchedSpotIndicatorData(flLine, dotData);
  //   }).toList();
  // }

  static SideTitleWidget getLeftTitleWidget(String text, TitleMeta meta) {
    return SideTitleWidget(
      axisSide: meta.axisSide,
      space: 8.0,
      angle: 0.0,
      child: Text(
        text,
        style: TextStyle(color: const Color(0xFFC8C9CC), fontSize: 12.sp, height: 1.3),
        textDirection: TextDirection.ltr,
        textAlign: TextAlign.left,
      ),
    );
  }

  static SideTitleWidget getBottomTitleWidget(String text, TitleMeta meta, {int maxWidth = 50}) {
    return SideTitleWidget(
      axisSide: meta.axisSide,
      space: 8.0,
      angle: 0.0,
      child: SizedBox(
        width: maxWidth.w,
        child: Text(
          text,
          overflow: TextOverflow.clip,
          style: TextStyle(color: const Color(0xFF646566), fontSize: 10.sp, height: 1.2),
          textDirection: TextDirection.rtl,
          textAlign: TextAlign.center,
        ),
      ),
    );
  }
}

==> tengits_widgets-0.0.10.tar.gz: lib/chart/src/style/chart_common_style.dart <==
import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class TLChartCommonStyle {
  ///
  static Color toolTipBgColor = Colors.black.withOpacity(0.8);

  ///
  static BarTooltipItem getBarTooltipItem(String text, {Color? color}) {
    return BarTooltipItem(
      text,
      TextStyle(
        color: color ?? Colors.white,
        fontSize: 12.sp,
        fontWeight: FontWeight.w400,
      ),
      textAlign: TextAlign.left,
    );
  }

  ///
  static FlBorderData flBorderData = FlBorderData(
    show: true,
    border: Border.symmetric(
      horizontal: BorderSide(color: const Color(0xFFF2F3F5), width: 1.w),
      vertical: BorderSide(color: Colors.transparent, width: 16.w),
    ),
  );

  static FlGridData getGridData(double? horizontalInterval) {
    return FlGridData(
      show: true,
      drawHorizontalLine: true,
      drawVerticalLine: false,
      horizontalInterval: horizontalInterval,
      getDrawingHorizontalLine: (double value) {
        return const FlLine(color: Color(0xFFF2F3F5), strokeWidth: 1);
      },
    );
  }

  // static LineTooltipItem getLineTooltipItems(Color? color, String text) {
  //   final textStyle = TextStyle(
  //     color: color,
  //     fontWeight: FontWeight.w400,
  //     fontSize: 12.sp,
  //   );
  //   return LineTooltipItem(text, textStyle, textAlign: TextAlign.left);
  // }

  // static List<TouchedSpotIndicatorData?> getTouchedSpotIndicator(LineChartBarData barData, List<int> indicators) {
  //   return indicators.map((int index) {
  //     final flLine = FlLine(color: const Color(0xFF5DACFB), strokeWidth: 0.5);

  //     final dotData = FlDotData();

  //     return TouchedSpotIndicatorData(flLine, dotData);
  //   }).toList();
  // }

  static SideTitleWidget getLeftTitleWidget(String text, TitleMeta meta) {
    return SideTitleWidget(
      axisSide: meta.axisSide,
      space: 8.0,
      angle: 0.0,
      child: Text(
        text,
        style: TextStyle(color: const Color(0xFFC8C9CC), fontSize: 12.sp, height: 1.3),
        textDirection: TextDirection.ltr,
        textAlign: TextAlign.left,
      ),
    );
  }

  static SideTitleWidget getBottomTitleWidget(String text, TitleMeta meta, {int maxWidth = 50}) {
    return SideTitleWidget(
      axisSide: meta.axisSide,
      space: 8.0,
      angle: 0.0,
      child: SizedBox(
        width: maxWidth.w,
        child: Text(
          text,
          overflow: TextOverflow.clip,
          style: TextStyle(color: const Color(0xFF646566), fontSize: 10.sp, height: 1.2),
          textDirection: TextDirection.rtl,
          textAlign: TextAlign.center,
        ),
      ),
    );
  }
}
